; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a penguin colony plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "penguin_plot.pro" and run it like this::
;       IDL> .RUN penguin_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 2 February 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Penguin_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
    iceFile = 'sicINC2.dat'
    gpdFile = 'S3B_gv.gpd'
    
    ; Hard coded penquin data.
    lon_col = [76.88,50.74,8.31,-8.13,64.00,-110.17,167.04,103.11,-103.70, $
              -15.13,169.43,69.70,170.56,165.38,48.00,158.10,169.64,158.41, $
              -26.56,-68.70,-60.56,-19.12,-157.74,59.38,168.40,89.11,-47.32, $
              -27.20,93.01,-61.00,85.00,57.30,14.45,-131.57,-33.65,146.45, $
              147.00,-64.46,-98.49,39.35,110.20,-100.00,81.55,140.01,8.31, $
              27.25,34.39,-1.38,73.72,100.00,-60.85,-78.75,-57.46,-23.02, $
              60.88,-125.59,81.34,158.30,166.40]  
    lat_col = [-69.28,-66.77,-69.94,-70.62,-67.40,-74.37,-76.94,-65.28,-74.18, $
               -72.14,-77.51,-67.88,-71.98,-74.65,-67.30,-77.70,-73.34,-69.33, $
               -76.01,-67.90,-70.68,-72.86,-77.13,-67.33,-76.18,-66.48,-77.74, $
               -75.52,-66.53,-66.10,-66.30,-66.64,-69.37,-74.36,-77.27,-66.93, $
               -68.22,-64.06,-71.75,-69.10,-65.93,-70.10,-65.55,-66.67,-69.94, $
               -69.97,-68.78,-70.05,-69.73,-66.00,-74.38,-72.31,-64.52,-74.16, $
               -67.48,-73.43,-67.05,-69.40,-70.44] 
               
    sto_gr = [0.0011,-0.0028 ,-0.0019 ,0 ,0.0015,-0.0001 ,0.0006,-0.003,-0.0016 , $
            -0.0005 ,0.0006,0.0016,0.0008,0.0003,-0.0042 ,0.0005,0.0008,0.0006,-0.0002 , $
            -0.0071 ,0.0005,-0.0007,0.0007,0.0009,0.0005,-0.0018 ,0.0017,-0.0004 ,-0.0029 , $
            0.0004,-0.0001 ,0.0003,-0.0025 ,-0.0043 ,0.0004,-0.0017 ,-0.0017 ,-0.0005 , $
            -0.0023 ,-0.0065 ,-0.0023 ,-0.0022 ,0.0005,-0.0007 ,-0.0019 ,-0.0055 ,-0.0062 , $
            -0.0001 ,0.0014,-0.0029 ,0.0004,-0.0024 ,0.001 ,-0.0004 ,0.0012,-0.003,0.0005, $
            0.0005,0.0004]
           
    ; Read the image file.
    OpenR, lun, iceFile, /GET_LUN
    image = FltArr(316, 332)
    ReadU, lun, image
    Free_Lun, lun
    
    ; Reverse the image and divide by 10 to scale into 0 to 100.
    imager = Reverse(image, 2) / 10.0

    ; Display the ice image in the window.
    position = [0.125, 0.125, 0.875, 0.875]
    cgDisplay, 600, 600
    
    ; Load colors for the image.
    cgLoadCT, 5, /BREWER, NColors=100, Bottom=1
    TVLCT, cgColor('white', /Triple), 0
    cgImage, BytScl(imager, MIN=1, MAX=100), /KEEP_ASPECT, $
        POSITION=position, /ERASE
    
    ; Contour the ice concentration image.
    cgContour, imager, LEVELS=[15, 50, 90], /NOERASE, POSITION=position, /OnImage
    
    ; Create a map coordinate space.
    map = Obj_New('MapCoord', 106, SEMIMAJOR_AXIS=6378273.0, SEMIMINOR_AXIS=6356889.5, $
                   CENTER_LATITUDE=-70.0, CENTER_LONGITUDE=0)
                   
    ; Find the map boundaries.
    success = cgFindMapBoundary(gpdFile, b, XRANGE=xrange, YRANGE=yrange)
    IF ~success THEN Message, 'Could not find the grid boundary.'
    
    ; Configure the map object.
    map -> SetProperty, XRANGE=xrange, YRANGE=yrange, POSITION=position
    
    ; Add a map overlay.
    continent = Obj_New('Map_Outline', MAP_OBJECT=map, COLOR='grey', /FILL)
    
    ; Add a map grid overlay.
    grid = Obj_New('Map_Grid', MAP_OBJECT=map, COLOR='charcoal', $
        LATS=[-80, -70, -60, -50], LONS=Findgen(11)*36)
    
    ; Draw the map coordinates.
    map -> Draw
    continent -> Draw
    continent -> SetProperty, COLOR='charcoal', FILE=0
    continent -> Draw
    grid -> Draw
    
    ; Prepare the colonies for drawing.
    colors = Fix(cgScaleVector(sto_gr, 1, 255))
    xy = Map_Proj_Forward(lon_col, lat_col, MAP_STRUCTURE=map->GetMapStructure())
    radius = (xrange[1] - xrange[0]) / 100.0
    cgLoadCT, 26, /BREWER
    TVCircle, radius*1.75, xy[0,*], xy[1,*], COLOR=cgColor(StrTrim(colors,2)), /FILL, /DATA
    
    FOR j=0,N_Elements(colors)-1 DO BEGIN
        cgText, (xy[0,*])[j], (xy[1,*])[j]-45000, StrTrim(j,2), ALIGN=0.5, $
            COLOR='red7', CHARSIZE=0.50
    ENDFOR
    
    ; Colony Vitality color bar.
    cgLoadCT, 26, /BREWER
    cgColorbar, DIVISIONS=2, TICKNAMES=['Low', 'Medium', 'High'], POSITION=[0.1, 0.925, 0.9, 0.95], $
        ANNOTATECOLOR='black', TITLE='Colony Vitality',  TLOCATION='TOP'
        
    ; Ice concentration color bar.
    cgLoadCT, 5, /BREWER
    cgColorbar, DIVISIONS=5, POSITION=[0.15, 0.05, 0.18, 0.30], /VERTICAL, $
        ANNOTATECOLOR='black', TITLE='Ice Concentration', RANGE=[0,100]
        
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Penguin_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Penguin_Plot', WAspect=1.0, $
     WTitle='Penquin Colony Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'penguin_plot.ps'
  Penguin_Plot
  cgPS_Close
  
  ; Create a PNG file.
  cgPS2Raster, 'penguin_plot.ps', /PNG, /Portrait

END